@@ -43,14 +43,19 @@ The result::
 
     paver paverdocs
     
-* <project name>/src contain your package. All project details,
-  shared by Paver and Sphinx, are set in
-  <project name>/src/<package name>/__init__.py.
+* <project name>/src contain your package.
   
 * <project name>/docs/source/ will contains your documentation source. conf.py
-  is Sphinx configuration file.
+  is Sphinx' configuration file.
   Check `Sphinx' documentation <http://sphinx.pocoo.org/>`_ for more details.
   
+.. note::
+    The version number, the project name and author name(s) are set in 
+    ``pavement.py`` and shared with ``docs/source/conf.py``.
+    
+    However licence and copyright information are hard coded into ``LICENCE``,
+    ``pavement.py``, ``docs/source/conf`` and ``src/<package>/__init__.py``.
+    
 """
 from datetime import date
 import os
@@ -111,10 +116,12 @@ ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 
-DEFAULT_NAME = Git(os.getcwd()).config('user.name').strip()
+DEFAULT_NAME = Git(os.getcwd()).config(
+    'user.name', with_exceptions=False).strip()
 DEFAULT_NAME = DEFAULT_NAME or os.getlogin()
 
-DEFAULT_EMAIL = Git(os.getcwd()).config('user.email').strip()
+DEFAULT_EMAIL = Git(os.getcwd()).config(
+    'user.email', with_exceptions=False).strip()
 
 
 class GithubTemplate(Template):
